@@ -56,7 +56,7 @@ sub execute {
 	$oldq = $query;
 	return	unless($query);
 
-#print STDERR "\n# query=[$query]";
+#print STDERR "\n# query=[$query]\n";
 #print STDERR "\n# arg=[$arg]\n";
 
 	if($query =~ /SELECT phrase FROM  phrasebook WHERE keyword=\? AND   dictionary=\?/) {
@@ -70,6 +70,10 @@ sub execute {
 		$dbh->{array} = ['Welcome to [% my %] world. It is a nice [% place %].'];
 		}
 	}
+
+    elsif($query =~ /SELECT dictonary FROM  phrasebook/) {
+		$dbh->{array} = [['DEF'],['ONE']];
+	}
 }
 sub fetchrow_hashref {
 	return shift @{$dbh->{hash}}}
